#
# spec file for package kuttl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name kubectl-kuttl

Name:           kuttl
Version:        0.22.0
Release:        1.2
Summary:        KUbernetes Test TooL
License:        Apache-2.0
URL:            https://github.com/kudobuilder/kuttl
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh

%description
KUbernetes Test TooL (KUTTL) provides a declarative approach to test Kubernetes
Operators.

KUTTL is designed for testing operators, however it can declaratively test any
kubernetes objects.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# COMMIT_HASH will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/kudobuilder/kuttl/pkg/version.gitVersion=%{version} \
   -X github.com/kudobuilder/kuttl/pkg/version.gitCommit=${COMMIT_HASH:0:8} \
   -X github.com/kudobuilder/kuttl/pkg/version.buildDate=$BUILD_DATE" \
   -o bin/%{executable_name} ./cmd/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Thu Feb 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.22.0:
  * chore(deps): bump github.com/spf13/cobra from 1.8.1 to 1.9.1
    (#611)
  * chore(deps): bump the kubernetes group with 8 updates (#610)
  * chore(deps): bump github.com/google/cel-go from 0.23.0 to
    0.23.2 (#608)
  * chore(deps): bump github.com/spf13/pflag from 1.0.5 to 1.0.6
    (#607)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.21.0:
  * chore(deps): bump github.com/google/cel-go from 0.22.0 to
    0.23.0 (#606)
  * chore: explicitly add quotes to error format (#605)
  * chore(deps): bump the kubernetes group across 1 directory with
    7 updates (#604)
  * chore(deps): bump github.com/docker/docker (#603)
  * [KEP-0009] feat: add expression based assertions (#576)
  * chore(deps): bump sigs.k8s.io/controller-runtime in the
    kubernetes group (#600)
  * chore(deps): bump sigs.k8s.io/controller-tools in the
    kubernetes group (#599)
  * chore(deps): bump github.com/docker/docker (#598)
  * Bump sigs.k8s.io/kind in the kubernetes group across 1
    directory (#597)
  * Bump go, k8s deps and linter versions, and some fixes (#596)
  * refactor: moves kubernetes utilities to `pkg/kubernetes` (#590)
  * Bump github.com/docker/docker (#594)
  * Bump sigs.k8s.io/controller-runtime in the kubernetes group
    (#592)
  * fix: make sure goreleaser config matches current schema (#588)
* Wed Dec  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.20.0:
  * Highlights
  - feat: Configurable report granularity (#581)
  - feat: add context switching in TestStep (#560)
  * Bug Fixes
  - Allow for processing tls-server-name attribute in kubeconfig
    context (#587)
  - fix: lock testsuite and sort child testcases (#585)
  - Clarify help terminology (#583)
  - fix: handle redundant deletion of Namespace (#566)
  - Remove mention of unsupported flag (#561)
  * Other Changes
  - chore: pre-factor code related to junit reporting (#580)
  - Make 0009-expression-based-assertions.md implementable (#574)
  - chore: add Expression-Based Assertions KEP (#568)
  * Dependency bumps
  - Bump go version to 1.22.7 (#582)
  - Bump the kubernetes group with 6 updates (#563, #571, #577)
  - Bump github.com/stretchr/testify from 1.9.0 to 1.10.0 (#578)
  - Bump github.com/Masterminds/semver/v3 from 3.3.0 to 3.3.1
    (#579)
  - Bump sigs.k8s.io/kind from 0.24.0 to 0.25.0 in the kubernetes
    group (#573)
  - Bump sigs.k8s.io/controller-tools from 0.16.3 to 0.16.5 in
    the kubernetes group (#570, #572)
  - Bump github.com/docker/docker from 27.2.0+incompatible to
    27.3.1+incompatible (#564, #567)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.19.0:
  * Bump github.com/Masterminds/semver/v3 from 3.2.1 to 3.3.0
    (#555)
  * Bump sigs.k8s.io/controller-tools in the kubernetes group
    (#554)
  * Bump github.com/docker/docker (#556)
  * feat: add user impersonation to all commands  (#549)
  * Bump github.com/docker/docker (#551)
  * Bump the kubernetes group with 8 updates (#550)
  * Make is possible to build with Go 1.23. (#548)
  * Bump github.com/docker/docker (#545)
  * Bump the kubernetes group with 5 updates (#544)
* Thu Jul 11 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package kuttl: KUbernetes Test TooL
